Enum sdl2::controller::Button
[−]
[src]
pub enum Button {
A,
B,
X,
Y,
Back,
Guide,
Start,
LeftStick,
RightStick,
LeftShoulder,
RightShoulder,
DPadUp,
DPadDown,
DPadLeft,
DPadRight,
}Variants
A | |
B | |
X | |
Y | |
Back | |
Guide | |
Start | |
LeftStick | |
RightStick | |
LeftShoulder | |
RightShoulder | |
DPadUp | |
DPadDown | |
DPadLeft | |
DPadRight |
Methods
impl Button
fn from_string(button: &str) -> Option<Button>
Return the Button from a string description in the same format used by the game controller mapping strings.
fn get_string(self) -> String
Return a string for a given button in the same format using by the game controller mapping strings